@@ -5,13 +5,11 @@
 package org.wildfly.clustering.web.undertow.session;
 
 import java.util.Collections;
-import java.util.HashMap;
 import java.util.Map;
 import java.util.Set;
 
-import org.wildfly.clustering.web.session.ImmutableSession;
-import org.wildfly.clustering.web.session.ImmutableSessionAttributes;
-import org.wildfly.clustering.web.session.ImmutableSessionMetaData;
+import org.wildfly.clustering.session.ImmutableSession;
+import org.wildfly.clustering.session.ImmutableSessionMetaData;
 
 import io.undertow.server.HttpServerExchange;
 import io.undertow.server.session.Session;
@@ -26,7 +24,7 @@ public class DistributableImmutableSession implements Session {
 
     private final SessionManager manager;
     private final String id;
-    private final Map<String, Object> attributes = new HashMap<>();
+    private final Map<String, Object> attributes;
     private final long creationTime;
     private final long lastAccessedTime;
     private final int maxInactiveInterval;
@@ -34,10 +32,7 @@ public class DistributableImmutableSession implements Session {
     public DistributableImmutableSession(SessionManager manager, ImmutableSession session) {
         this.manager = manager;
         this.id = session.getId();
-        ImmutableSessionAttributes attributes = session.getAttributes();
-        for (String name: attributes.getAttributeNames()) {
-            this.attributes.put(name, attributes.getAttribute(name));
-        }
+        this.attributes = Map.copyOf(session.getAttributes());
         ImmutableSessionMetaData metaData = session.getMetaData();
         this.creationTime = metaData.getCreationTime().toEpochMilli();
         this.lastAccessedTime = metaData.getLastAccessStartTime().toEpochMilli();
