@@ -1,23 +1,6 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2013, Red Hat, Inc., and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 package org.wildfly.clustering.web.undertow.session;
 
@@ -26,18 +9,17 @@ import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertSame;
 import static org.junit.Assert.assertTrue;
+import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
-import static org.mockito.Mockito.reset;
+import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.verifyNoInteractions;
 import static org.mockito.Mockito.when;
 
-import java.time.Duration;
 import java.util.Collections;
 import java.util.Map;
 import java.util.Set;
-import java.util.function.Supplier;
 
 import io.undertow.UndertowOptions;
 import io.undertow.connector.ByteBufferPool;
@@ -52,14 +34,14 @@ import io.undertow.util.Protocols;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
-import org.wildfly.clustering.ee.Batch;
-import org.wildfly.clustering.ee.Batcher;
-import org.wildfly.clustering.web.session.ImmutableSession;
-import org.wildfly.clustering.web.session.ImmutableSessionMetaData;
-import org.wildfly.clustering.web.session.Session;
-import org.wildfly.clustering.web.session.SessionManager;
-import org.wildfly.clustering.web.session.SessionMetaData;
-import org.wildfly.common.function.Functions;
+import org.wildfly.clustering.cache.batch.Batch;
+import org.wildfly.clustering.cache.batch.SuspendedBatch;
+import org.wildfly.clustering.context.Context;
+import org.wildfly.clustering.function.Supplier;
+import org.wildfly.clustering.session.Session;
+import org.wildfly.clustering.session.SessionManager;
+import org.wildfly.clustering.session.SessionMetaData;
+import org.wildfly.clustering.session.SessionStatistics;
 import org.xnio.OptionMap;
 import org.xnio.StreamConnection;
 import org.xnio.channels.Configurable;
@@ -70,15 +52,22 @@ import org.xnio.conduits.StreamSourceConduit;
 
 public class DistributableSessionManagerTestCase {
     private final String deploymentName = "mydeployment.war";
-    private final SessionManager<Map<String, Object>, Batch> manager = mock(SessionManager.class);
+    private final SessionManager<Map<String, Object>> manager = mock(SessionManager.class);
     private final SessionListener listener = mock(SessionListener.class);
     private final SessionListeners listeners = new SessionListeners();
+    private final SessionStatistics stats = mock(SessionStatistics.class);
     private final RecordableSessionManagerStatistics statistics = mock(RecordableSessionManagerStatistics.class);
+    private final Supplier<String> identifierFactory = mock(Supplier.class);
+    private final Supplier<Batch> batchFactory = mock(Supplier.class);
 
     private DistributableSessionManager adapter;
 
     @Before
     public void init() {
+        when(this.manager.getStatistics()).thenReturn(this.stats);
+        when(this.manager.getBatchFactory()).thenReturn(this.batchFactory);
+        when(this.manager.getIdentifierFactory()).thenReturn(this.identifierFactory);
+
         DistributableSessionManagerConfiguration config = mock(DistributableSessionManagerConfiguration.class);
 
         when(config.getDeploymentName()).thenReturn(this.deploymentName);
@@ -105,8 +94,6 @@ public class DistributableSessionManagerTestCase {
 
     @Test
     public void stop() {
-        when(this.manager.getStopTimeout()).thenReturn(Duration.ZERO);
-
         this.adapter.stop();
 
         verify(this.manager).stop();
@@ -122,12 +109,11 @@ public class DistributableSessionManagerTestCase {
         ConduitStreamSinkChannel sinkChannel = new ConduitStreamSinkChannel(configurable, sinkConduit);
         StreamConnection stream = mock(StreamConnection.class);
         String id = "foo";
-        Supplier<String> identifierFactory = Functions.constantSupplier(id);
         int expectedTimeout = 10;
 
         this.adapter.setDefaultSessionTimeout(expectedTimeout);
 
-        when(this.manager.getIdentifierFactory()).thenReturn(identifierFactory);
+        when(this.identifierFactory.get()).thenReturn(id);
         when(stream.getSourceChannel()).thenReturn(sourceChannel);
         when(stream.getSinkChannel()).thenReturn(sinkChannel);
 
@@ -152,19 +138,21 @@ public class DistributableSessionManagerTestCase {
     @Test
     public void createSessionNoSessionId() {
         HttpServerExchange exchange = new HttpServerExchange(null);
-        Supplier<String> identifierFactory = mock(Supplier.class);
-        Batcher<Batch> batcher = mock(Batcher.class);
         Batch batch = mock(Batch.class);
+        SuspendedBatch suspendedBatch = mock(SuspendedBatch.class);
+        Context<Batch> context = mock(Context.class);
         SessionConfig config = mock(SessionConfig.class);
         Session<Map<String, Object>> session = mock(Session.class);
         SessionMetaData metaData = mock(SessionMetaData.class);
         String sessionId = "session";
 
-        when(this.manager.getIdentifierFactory()).thenReturn(identifierFactory);
-        when(identifierFactory.get()).thenReturn(sessionId);
+        when(this.batchFactory.get()).thenReturn(batch);
+        when(batch.suspend()).thenReturn(suspendedBatch);
+        when(suspendedBatch.resume()).thenReturn(batch);
+        when(suspendedBatch.resumeWithContext()).thenReturn(context);
+        when(context.get()).thenReturn(batch);
+        when(this.identifierFactory.get()).thenReturn(sessionId);
         when(this.manager.createSession(sessionId)).thenReturn(session);
-        when(this.manager.getBatcher()).thenReturn(batcher);
-        when(batcher.createBatch()).thenReturn(batch);
         when(session.getId()).thenReturn(sessionId);
         when(session.getMetaData()).thenReturn(metaData);
         when(metaData.isNew()).thenReturn(true);
@@ -175,7 +163,7 @@ public class DistributableSessionManagerTestCase {
 
         verify(this.listener).sessionCreated(sessionAdapter, exchange);
         verify(config).setSessionId(exchange, sessionId);
-        verify(batcher).suspendBatch();
+        verify(batch).suspend();
         verify(this.statistics).record(metaData);
 
         String expected = "expected";
@@ -188,17 +176,21 @@ public class DistributableSessionManagerTestCase {
     @Test
     public void createSessionSpecifiedSessionId() {
         HttpServerExchange exchange = new HttpServerExchange(null);
-        Batcher<Batch> batcher = mock(Batcher.class);
         Batch batch = mock(Batch.class);
+        SuspendedBatch suspendedBatch = mock(SuspendedBatch.class);
+        Context<Batch> context = mock(Context.class);
         SessionConfig config = mock(SessionConfig.class);
         Session<Map<String, Object>> session = mock(Session.class);
         SessionMetaData metaData = mock(SessionMetaData.class);
         String sessionId = "session";
 
+        when(this.batchFactory.get()).thenReturn(batch);
+        when(batch.suspend()).thenReturn(suspendedBatch);
+        when(suspendedBatch.resume()).thenReturn(batch);
+        when(suspendedBatch.resumeWithContext()).thenReturn(context);
+        when(context.get()).thenReturn(batch);
         when(config.findSessionId(exchange)).thenReturn(sessionId);
         when(this.manager.createSession(sessionId)).thenReturn(session);
-        when(this.manager.getBatcher()).thenReturn(batcher);
-        when(batcher.createBatch()).thenReturn(batch);
         when(session.getId()).thenReturn(sessionId);
         when(session.getMetaData()).thenReturn(metaData);
         when(metaData.isNew()).thenReturn(true);
@@ -208,8 +200,9 @@ public class DistributableSessionManagerTestCase {
         assertNotNull(sessionAdapter);
 
         verify(this.listener).sessionCreated(sessionAdapter, exchange);
-        verify(batcher).suspendBatch();
+        verify(batch).suspend();
         verify(this.statistics).record(metaData);
+        verifyNoInteractions(this.identifierFactory);
 
         String expected = "expected";
         when(session.getId()).thenReturn(expected);
@@ -221,15 +214,19 @@ public class DistributableSessionManagerTestCase {
     @Test
     public void createSessionAlreadyExists() {
         HttpServerExchange exchange = new HttpServerExchange(null);
-        Batcher<Batch> batcher = mock(Batcher.class);
         Batch batch = mock(Batch.class);
+        SuspendedBatch suspendedBatch = mock(SuspendedBatch.class);
+        Context<Batch> context = mock(Context.class);
         SessionConfig config = mock(SessionConfig.class);
         String sessionId = "session";
 
+        when(this.batchFactory.get()).thenReturn(batch);
+        when(batch.suspend()).thenReturn(suspendedBatch);
+        when(suspendedBatch.resume()).thenReturn(batch);
+        when(suspendedBatch.resumeWithContext()).thenReturn(context);
+        when(context.get()).thenReturn(batch);
         when(config.findSessionId(exchange)).thenReturn(sessionId);
         when(this.manager.createSession(sessionId)).thenReturn(null);
-        when(this.manager.getBatcher()).thenReturn(batcher);
-        when(batcher.createBatch()).thenReturn(batch);
 
         IllegalStateException exception = null;
         try {
@@ -240,6 +237,7 @@ public class DistributableSessionManagerTestCase {
 
         assertNotNull(exception);
 
+        verifyNoInteractions(this.identifierFactory);
         verify(batch).discard();
         verify(batch).close();
     }
@@ -247,19 +245,25 @@ public class DistributableSessionManagerTestCase {
     @Test
     public void getSession() {
         HttpServerExchange exchange = new HttpServerExchange(null);
-        Batcher<Batch> batcher = mock(Batcher.class);
         Batch batch = mock(Batch.class);
+        SuspendedBatch suspendedBatch = mock(SuspendedBatch.class);
+        Context<Batch> context = mock(Context.class);
         SessionConfig config = mock(SessionConfig.class);
         Session<Map<String, Object>> session = mock(Session.class);
         SessionMetaData metaData = mock(SessionMetaData.class);
         String sessionId = "session";
 
+        when(this.batchFactory.get()).thenReturn(batch);
+        when(batch.suspend()).thenReturn(suspendedBatch);
+        when(suspendedBatch.resume()).thenReturn(batch);
+        when(suspendedBatch.resumeWithContext()).thenReturn(context);
+        when(context.get()).thenReturn(batch);
         when(config.findSessionId(exchange)).thenReturn(sessionId);
         when(this.manager.findSession(sessionId)).thenReturn(session);
-        when(this.manager.getBatcher()).thenReturn(batcher);
-        when(batcher.createBatch()).thenReturn(batch);
         when(session.getId()).thenReturn(sessionId);
+        when(session.isValid()).thenReturn(true);
         when(session.getMetaData()).thenReturn(metaData);
+        when(metaData.isExpired()).thenReturn(false);
         when(metaData.isNew()).thenReturn(false);
 
         io.undertow.server.session.Session sessionAdapter = this.adapter.getSession(exchange, config);
@@ -267,8 +271,9 @@ public class DistributableSessionManagerTestCase {
         assertNotNull(sessionAdapter);
 
         verifyNoInteractions(this.statistics);
+        verifyNoInteractions(this.identifierFactory);
 
-        verify(batcher).suspendBatch();
+        verify(batch).suspend();
 
         String expected = "expected";
         when(session.getId()).thenReturn(expected);
@@ -281,58 +286,154 @@ public class DistributableSessionManagerTestCase {
     public void getSessionNoSessionId() {
         HttpServerExchange exchange = new HttpServerExchange(null);
         SessionConfig config = mock(SessionConfig.class);
+        Batch batch = mock(Batch.class);
+        SuspendedBatch suspendedBatch = mock(SuspendedBatch.class);
+        Context<Batch> context = mock(Context.class);
 
+        when(this.batchFactory.get()).thenReturn(batch);
+        when(batch.suspend()).thenReturn(suspendedBatch);
+        when(suspendedBatch.resume()).thenReturn(batch);
+        when(suspendedBatch.resumeWithContext()).thenReturn(context);
+        when(context.get()).thenReturn(batch);
         when(config.findSessionId(exchange)).thenReturn(null);
 
         io.undertow.server.session.Session sessionAdapter = this.adapter.getSession(exchange, config);
 
         assertNull(sessionAdapter);
+
+        verify(batch).discard();
+        verify(batch).close();
     }
 
     @Test
     public void getSessionInvalidCharacters() {
         HttpServerExchange exchange = new HttpServerExchange(null);
         SessionConfig config = mock(SessionConfig.class);
+        Batch batch = mock(Batch.class);
+        SuspendedBatch suspendedBatch = mock(SuspendedBatch.class);
+        Context<Batch> context = mock(Context.class);
         String sessionId = "session+";
 
+        when(this.batchFactory.get()).thenReturn(batch);
+        when(batch.suspend()).thenReturn(suspendedBatch);
+        when(suspendedBatch.resume()).thenReturn(batch);
+        when(suspendedBatch.resumeWithContext()).thenReturn(context);
+        when(context.get()).thenReturn(batch);
         when(config.findSessionId(exchange)).thenReturn(sessionId);
 
         io.undertow.server.session.Session sessionAdapter = this.adapter.getSession(exchange, config);
 
         assertNull(sessionAdapter);
 
+        verify(this.manager, never()).findSession(sessionId);
+        verify(batch).discard();
+        verify(batch).close();
+
         sessionAdapter = this.adapter.getSession(sessionId);
 
         assertNull(sessionAdapter);
 
         verify(this.manager, never()).findSession(sessionId);
+        verify(batch, times(2)).close();
     }
 
-
     @Test
     public void getSessionNotExists() {
         HttpServerExchange exchange = new HttpServerExchange(null);
-        Batcher<Batch> batcher = mock(Batcher.class);
         Batch batch = mock(Batch.class);
+        SuspendedBatch suspendedBatch = mock(SuspendedBatch.class);
+        Context<Batch> context = mock(Context.class);
         SessionConfig config = mock(SessionConfig.class);
         String sessionId = "session";
 
+        when(this.batchFactory.get()).thenReturn(batch);
+        when(batch.suspend()).thenReturn(suspendedBatch);
+        when(suspendedBatch.resume()).thenReturn(batch);
+        when(suspendedBatch.resumeWithContext()).thenReturn(context);
+        when(context.get()).thenReturn(batch);
         when(config.findSessionId(exchange)).thenReturn(sessionId);
         when(this.manager.findSession(sessionId)).thenReturn(null);
-        when(this.manager.getBatcher()).thenReturn(batcher);
-        when(batcher.createBatch()).thenReturn(batch);
+        when(this.manager.getBatchFactory()).thenReturn(Supplier.of(batch));
 
         io.undertow.server.session.Session sessionAdapter = this.adapter.getSession(exchange, config);
 
         assertNull(sessionAdapter);
 
+        verify(batch).discard();
+        verify(batch).close();
+    }
+
+    @Test
+    public void getSessionInvalid() {
+        HttpServerExchange exchange = new HttpServerExchange(null);
+        Batch batch = mock(Batch.class);
+        SuspendedBatch suspendedBatch = mock(SuspendedBatch.class);
+        Context<Batch> context = mock(Context.class);
+        SessionConfig config = mock(SessionConfig.class);
+        Session<Map<String, Object>> session = mock(Session.class);
+        SessionMetaData metaData = mock(SessionMetaData.class);
+        String sessionId = "session";
+
+        when(this.batchFactory.get()).thenReturn(batch);
+        when(batch.suspend()).thenReturn(suspendedBatch);
+        when(suspendedBatch.resume()).thenReturn(batch);
+        when(suspendedBatch.resumeWithContext()).thenReturn(context);
+        when(context.get()).thenReturn(batch);
+        when(config.findSessionId(exchange)).thenReturn(sessionId);
+        when(this.manager.findSession(sessionId)).thenReturn(session);
+        when(session.getId()).thenReturn(sessionId);
+        when(session.isValid()).thenReturn(false);
+        when(session.getMetaData()).thenReturn(metaData);
+        when(metaData.isExpired()).thenReturn(false);
+        when(metaData.isNew()).thenReturn(false);
+
+        io.undertow.server.session.Session sessionAdapter = this.adapter.getSession(exchange, config);
+
+        assertNull(sessionAdapter);
+
+        verifyNoInteractions(this.statistics);
+
+        verify(batch).discard();
+        verify(batch).close();
+    }
+
+    @Test
+    public void getSessionExpired() {
+        HttpServerExchange exchange = new HttpServerExchange(null);
+        Batch batch = mock(Batch.class);
+        SuspendedBatch suspendedBatch = mock(SuspendedBatch.class);
+        Context<Batch> context = mock(Context.class);
+        SessionConfig config = mock(SessionConfig.class);
+        Session<Map<String, Object>> session = mock(Session.class);
+        SessionMetaData metaData = mock(SessionMetaData.class);
+        String sessionId = "session";
+
+        when(this.batchFactory.get()).thenReturn(batch);
+        when(batch.suspend()).thenReturn(suspendedBatch);
+        when(suspendedBatch.resume()).thenReturn(batch);
+        when(suspendedBatch.resumeWithContext()).thenReturn(context);
+        when(context.get()).thenReturn(batch);
+        when(config.findSessionId(exchange)).thenReturn(sessionId);
+        when(this.manager.findSession(sessionId)).thenReturn(session);
+        when(session.getId()).thenReturn(sessionId);
+        when(session.isValid()).thenReturn(true);
+        when(session.getMetaData()).thenReturn(metaData);
+        when(metaData.isExpired()).thenReturn(true);
+        when(metaData.isNew()).thenReturn(false);
+
+        io.undertow.server.session.Session sessionAdapter = this.adapter.getSession(exchange, config);
+
+        assertNull(sessionAdapter);
+
+        verifyNoInteractions(this.statistics);
+
+        verify(batch).discard();
         verify(batch).close();
-        verify(batcher, never()).suspendBatch();
     }
 
     @Test
     public void activeSessions() {
-        when(this.manager.getActiveSessions()).thenReturn(Collections.singleton("expected"));
+        when(this.stats.getActiveSessions()).thenReturn(Collections.singleton("expected"));
 
         int result = this.adapter.getActiveSessions().size();
 
@@ -349,7 +450,7 @@ public class DistributableSessionManagerTestCase {
     @Test
     public void getActiveSessions() {
         String expected = "expected";
-        when(this.manager.getActiveSessions()).thenReturn(Collections.singleton(expected));
+        when(this.stats.getActiveSessions()).thenReturn(Collections.singleton(expected));
 
         Set<String> result = this.adapter.getActiveSessions();
 
@@ -360,7 +461,7 @@ public class DistributableSessionManagerTestCase {
     @Test
     public void getAllSessions() {
         String expected = "expected";
-        when(this.manager.getLocalSessions()).thenReturn(Collections.singleton(expected));
+        when(this.stats.getSessions()).thenReturn(Collections.singleton(expected));
 
         Set<String> result = this.adapter.getAllSessions();
 
@@ -370,43 +471,24 @@ public class DistributableSessionManagerTestCase {
 
     @Test
     public void getSessionByIdentifier() {
-        Batcher<Batch> batcher = mock(Batcher.class);
-        Batch batch1 = mock(Batch.class);
-        Batch batch2 = mock(Batch.class);
-        ImmutableSession session = mock(ImmutableSession.class);
-        ImmutableSessionMetaData metaData = mock(ImmutableSessionMetaData.class);
+        Session<Map<String, Object>> session = mock(Session.class);
+        SessionMetaData metaData = mock(SessionMetaData.class);
         String id = "ABC123";
 
-        when(this.manager.getBatcher()).thenReturn(batcher);
-        when(batcher.createBatch()).thenReturn(batch1, batch2);
-        when(this.manager.readSession(id)).thenReturn(session);
-        when(session.getMetaData()).thenReturn(metaData);
-        when(metaData.isNew()).thenReturn(false);
-
-        io.undertow.server.session.Session result = this.adapter.getSession(id);
-
-        Assert.assertSame(id, result.getId());
-
-        verify(batch1).close();
-        verify(batch2).close();
-    }
-
-    @Test
-    public void getSessionByIdentifierNotExists() {
-        Batcher<Batch> batcher = mock(Batcher.class);
-        Batch batch = mock(Batch.class);
-        String id = "ABC123";
-
-        when(this.manager.getBatcher()).thenReturn(batcher);
-        when(batcher.createBatch()).thenReturn(batch);
-        when(this.manager.readSession(id)).thenReturn(null);
+        doReturn(session).when(this.manager).getDetachedSession(id);
+        doReturn(id).when(session).getId();
+        doReturn(metaData).when(session).getMetaData();
+        doReturn(false).when(session).isValid();
 
         io.undertow.server.session.Session result = this.adapter.getSession(id);
 
         Assert.assertNull(result);
 
-        verify(batch).close();
-        reset(batch);
+        doReturn(true).when(session).isValid();
+
+        result = this.adapter.getSession(id);
+
+        Assert.assertSame(id, result.getId());
     }
 
     @Test
