@@ -1,23 +1,6 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2012, Red Hat, Inc., and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 
 /**
@@ -43,6 +26,7 @@ import org.jboss.as.connector.logging.ConnectorLogger;
 import org.jboss.as.connector.services.driver.InstalledDriver;
 import org.jboss.as.connector.services.driver.registry.DriverRegistry;
 import org.jboss.as.connector.util.ConnectorServices;
+import org.jboss.as.controller.ModuleIdentifierUtil;
 import org.jboss.as.controller.OperationContext;
 import org.jboss.as.controller.OperationFailedException;
 import org.jboss.as.controller.OperationStepHandler;
@@ -88,14 +72,16 @@ public class InstalledDriversListOperationHandler implements OperationStepHandle
 
                         } else {
                             driverNode.get(DEPLOYMENT_NAME.getName());
-                            driverNode.get(DRIVER_MODULE_NAME.getName()).set(driver.getModuleName().getName());
-                            driverNode.get(MODULE_SLOT.getName()).set(
-                                    driver.getModuleName() != null ? driver.getModuleName().getSlot() : "");
+                            ModuleIdentifierUtil.parseModuleIdentifier(driver.getModuleName(), (parsedName, parsedSlot) -> {
+                                driverNode.get(DRIVER_MODULE_NAME.getName()).set(parsedName);
+                                driverNode.get(MODULE_SLOT.getName()).set(parsedSlot);
+                                return null;
+                            }, false, "main");
+
                             driverNode.get(DRIVER_DATASOURCE_CLASS_NAME.getName()).set(
                                     driver.getDataSourceClassName() != null ? driver.getDataSourceClassName() : "");
                             driverNode.get(DRIVER_XA_DATASOURCE_CLASS_NAME.getName()).set(
                                     driver.getXaDataSourceClassName() != null ? driver.getXaDataSourceClassName() : "");
-
                         }
                         driverNode.get(DATASOURCE_CLASS_INFO.getName()).set(
                                 dsClsInfoNode(serviceModuleLoader, driver.getModuleName(), driver.getDataSourceClassName(), driver.getXaDataSourceClassName()));
