@@ -1,23 +1,6 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2012, Red Hat, Inc., and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 
 package org.jboss.as.connector.subsystems.datasources;
@@ -25,8 +8,6 @@ package org.jboss.as.connector.subsystems.datasources;
 import java.util.Map;
 
 import org.jboss.as.connector.logging.ConnectorLogger;
-import org.jboss.as.connector.metadata.api.common.Credential;
-import org.jboss.as.connector.metadata.api.ds.DsSecurity;
 import org.jboss.as.controller.OperationContext;
 import org.jboss.as.controller.PathAddress;
 import org.jboss.as.controller.descriptions.ModelDescriptionConstants;
@@ -67,7 +48,7 @@ public class XMLXaDataSourceRuntimeHandler extends AbstractXMLDataSourceRuntimeH
     private void handleDatasourceAttribute(final String attributeName, final OperationContext context, final XaDataSource dataSource) {
         if (attributeName.equals(Constants.XA_DATASOURCE_CLASS.getName())) {
             setStringIfNotNull(context, dataSource.getXaDataSourceClass());
-        } else if (attributeName.equals(Constants.JNDI_NAME.getName())) {
+        } else if (attributeName.equals(org.jboss.as.connector.subsystems.common.jndi.Constants.JNDI_NAME.getName())) {
             setStringIfNotNull(context, dataSource.getJndiName());
         } else if (attributeName.equals(Constants.DATASOURCE_DRIVER.getName())) {
             setStringIfNotNull(context, dataSource.getDriver());
@@ -79,7 +60,7 @@ public class XMLXaDataSourceRuntimeHandler extends AbstractXMLDataSourceRuntimeH
             setStringIfNotNull(context, dataSource.getUrlProperty());
         } else if (attributeName.equals(Constants.URL_SELECTOR_STRATEGY_CLASS_NAME.getName())) {
             setStringIfNotNull(context, dataSource.getUrlSelectorStrategyClassName());
-        } else if (attributeName.equals(Constants.USE_JAVA_CONTEXT.getName())) {
+        } else if (attributeName.equals(org.jboss.as.connector.subsystems.common.jndi.Constants.USE_JAVA_CONTEXT.getName())) {
             setBooleanIfNotNull(context, dataSource.isUseJavaContext());
         } else if (attributeName.equals(Constants.ENABLED.getName())) {
             setBooleanIfNotNull(context, dataSource.isEnabled());
@@ -240,32 +221,9 @@ public class XMLXaDataSourceRuntimeHandler extends AbstractXMLDataSourceRuntimeH
         } else if (attributeName.equals(Constants.RECOVERY_PASSWORD.getName())) {
             //don't display the password
         } else if (attributeName.equals(Constants.RECOVERY_SECURITY_DOMAIN.getName())) {
-            if(dataSource.getRecovery() == null) {
-                return;
-            }
-            if(dataSource.getRecovery().getCredential() == null) {
-                return;
-            }
-            // safe assertion because all parsers create jboss Credential
-            assert dataSource.getRecovery().getCredential() instanceof Credential;
-            if (((Credential) dataSource.getRecovery().getCredential()).isElytronEnabled()) {
-                return;
-            }
-            setStringIfNotNull(context, dataSource.getRecovery().getCredential().getSecurityDomain());
-
+            // no longer supported
         } else if (attributeName.equals(Constants.RECOVERY_ELYTRON_ENABLED.getName())) {
-            if(dataSource.getRecovery() == null) {
-                return;
-            }
-            if(dataSource.getRecovery().getCredential() == null) {
-                return;
-            }
-            // safe assertion because all parsers create jboss Credential
-            assert dataSource.getRecovery().getCredential() instanceof Credential;
-            if (!((Credential) dataSource.getRecovery().getCredential()).isElytronEnabled()) {
-                return;
-            }
-            setBooleanIfNotNull(context, ((Credential) dataSource.getRecovery().getCredential()).isElytronEnabled());
+            setBooleanIfNotNull(context, true);
         } else if (attributeName.equals(Constants.RECOVERY_CREDENTIAL_REFERENCE.getName())) {
             //don't give out the credential-reference
         } else if (attributeName.equals(Constants.RECOVERY_AUTHENTICATION_CONTEXT.getName())) {
@@ -275,11 +233,6 @@ public class XMLXaDataSourceRuntimeHandler extends AbstractXMLDataSourceRuntimeH
             if(dataSource.getRecovery().getCredential() == null) {
                 return;
             }
-            // safe assertion because all parsers create jboss Credential
-            assert dataSource.getRecovery().getCredential() instanceof Credential;
-            if (!((Credential) dataSource.getRecovery().getCredential()).isElytronEnabled()) {
-                return;
-            }
             setStringIfNotNull(context, dataSource.getRecovery().getCredential().getSecurityDomain());
 
         } else if (attributeName.equals(Constants.RECOVER_PLUGIN_CLASSNAME.getName())) {
@@ -330,7 +283,10 @@ public class XMLXaDataSourceRuntimeHandler extends AbstractXMLDataSourceRuntimeH
             if (dataSource.getValidation().getExceptionSorter() == null) {
                 return;
             }
-            setStringIfNotNull(context, ((ModuleClassLoader)dataSource.getValidation().getExceptionSorter().getClassLoader()).getModule().toString());
+            ClassLoader exceptionSorterClassLoader = dataSource.getValidation().getExceptionSorter().getClassLoader();
+            if (exceptionSorterClassLoader instanceof ModuleClassLoader) {
+                setStringIfNotNull(context, ((ModuleClassLoader) exceptionSorterClassLoader).getModule().toString());
+            }
         } else if (attributeName.equals(Constants.EXCEPTION_SORTER_PROPERTIES.getName())) {
             if (dataSource.getValidation() == null) {
                 return;
@@ -360,7 +316,10 @@ public class XMLXaDataSourceRuntimeHandler extends AbstractXMLDataSourceRuntimeH
             if (dataSource.getValidation().getStaleConnectionChecker() == null) {
                 return;
             }
-            setStringIfNotNull(context, ((ModuleClassLoader)dataSource.getValidation().getStaleConnectionChecker().getClassLoader()).getModule().toString());
+            ClassLoader staleConnectionCheckerClassLoader = dataSource.getValidation().getStaleConnectionChecker().getClassLoader();
+            if (staleConnectionCheckerClassLoader instanceof ModuleClassLoader) {
+                setStringIfNotNull(context, ((ModuleClassLoader) staleConnectionCheckerClassLoader).getModule().toString());
+            }
         } else if (attributeName.equals(Constants.STALE_CONNECTION_CHECKER_PROPERTIES.getName())) {
             if (dataSource.getValidation() == null) {
                 return;
@@ -390,7 +349,10 @@ public class XMLXaDataSourceRuntimeHandler extends AbstractXMLDataSourceRuntimeH
             if (dataSource.getValidation().getValidConnectionChecker() == null) {
                 return;
             }
-            setStringIfNotNull(context, ((ModuleClassLoader)dataSource.getValidation().getValidConnectionChecker().getClassLoader()).getModule().toString());
+            ClassLoader validConnectionCheckerClassLoader = dataSource.getValidation().getValidConnectionChecker().getClassLoader();
+            if (validConnectionCheckerClassLoader instanceof ModuleClassLoader) {
+                setStringIfNotNull(context, ((ModuleClassLoader) validConnectionCheckerClassLoader).getModule().toString());
+            }
         } else if (attributeName.equals(Constants.VALID_CONNECTION_CHECKER_PROPERTIES.getName())) {
             if (dataSource.getValidation() == null) {
                 return;
@@ -438,31 +400,13 @@ public class XMLXaDataSourceRuntimeHandler extends AbstractXMLDataSourceRuntimeH
             if (dataSource.getSecurity() == null) {
                 return;
             }
-            // this is a safe assert because DsXmlParser will always create a wildfly DsSecurity metadata
-            assert dataSource.getSecurity() instanceof DsSecurity;
-            if (((DsSecurity) dataSource.getSecurity()).isElytronEnabled()) {
+            if (dataSource.getSecurity().getSecurityDomain() == null) {
                 return;
             }
-            setStringIfNotNull(context, dataSource.getSecurity().getSecurityDomain());
+            throw new IllegalStateException(ConnectorLogger.ROOT_LOGGER.legacySecurityNotSupported());
         } else if (attributeName.equals(Constants.ELYTRON_ENABLED.getName())) {
-            if (dataSource.getSecurity() == null) {
-                return;
-            }
-            // this is a safe assert because DsXmlParser will always create a wildfly DsSecurity metadata
-            assert dataSource.getSecurity() instanceof DsSecurity;
-            if (!((DsSecurity) dataSource.getSecurity()).isElytronEnabled()) {
-                return;
-            }
-            setBooleanIfNotNull(context, ((DsSecurity) dataSource.getSecurity()).isElytronEnabled());
+            setBooleanIfNotNull(context, true);
         } else if (attributeName.equals(Constants.AUTHENTICATION_CONTEXT.getName())) {
-            if (dataSource.getSecurity() == null) {
-                return;
-            }
-            // this is a safe assert because DsXmlParser will always create a wildfly DsSecurity metadata
-            assert dataSource.getSecurity() instanceof DsSecurity;
-            if (!((DsSecurity) dataSource.getSecurity()).isElytronEnabled()) {
-                return;
-            }
             setStringIfNotNull(context, dataSource.getSecurity().getSecurityDomain());
         } else if (attributeName.equals(Constants.REAUTH_PLUGIN_CLASSNAME.getName())) {
             if (dataSource.getSecurity() == null) {
