@@ -13,6 +13,9 @@ import static org.wildfly.extension.messaging.activemq.CommonAttributes.SUBSYSTE
 import static org.wildfly.extension.messaging.activemq.MessagingDependencies.getActiveMQDependencies;
 import static org.wildfly.extension.messaging.activemq.MessagingDependencies.getJGroupsDependencies;
 import static org.wildfly.extension.messaging.activemq.MessagingDependencies.getMessagingActiveMQGAV;
+import static org.wildfly.extension.messaging.activemq.MessagingExtension.BRIDGE_PATH;
+import static org.wildfly.extension.messaging.activemq.MessagingExtension.EXTERNAL_JMS_QUEUE_PATH;
+import static org.wildfly.extension.messaging.activemq.MessagingExtension.EXTERNAL_JMS_TOPIC_PATH;
 import static org.wildfly.extension.messaging.activemq.MessagingExtension.SERVER_PATH;
 import static org.wildfly.extension.messaging.activemq.MessagingExtension.SUBSYSTEM_PATH;
 
@@ -24,6 +27,7 @@ import java.util.Set;
 
 import org.jboss.as.controller.ModelVersion;
 import org.jboss.as.controller.PathAddress;
+import org.jboss.as.controller.capability.RuntimeCapability;
 import org.jboss.as.controller.security.CredentialReference;
 import org.jboss.as.model.test.FailedOperationTransformationConfig;
 import org.jboss.as.model.test.ModelTestControllerVersion;
@@ -35,24 +39,24 @@ import org.jboss.as.subsystem.test.KernelServicesBuilder;
 import org.jboss.dmr.ModelNode;
 import org.junit.Assert;
 import org.junit.Test;
-import org.wildfly.clustering.jgroups.spi.JGroupsDefaultRequirement;
-import org.wildfly.clustering.server.service.ClusteringDefaultRequirement;
-import org.wildfly.clustering.server.service.ClusteringRequirement;
+import org.wildfly.clustering.server.service.ClusteringServiceDescriptor;
+import org.wildfly.clustering.server.service.LegacyClusteringServiceDescriptor;
+import org.wildfly.extension.messaging.activemq.jms.ConnectionFactoryAttributes;
 
-public class MessagingActiveMQSubsystem_13_1_TestCase extends AbstractSubsystemBaseTest {
+public class MessagingActiveMQSubsystem_14_0_TestCase extends AbstractSubsystemBaseTest {
 
-    public MessagingActiveMQSubsystem_13_1_TestCase() {
+    public MessagingActiveMQSubsystem_14_0_TestCase() {
         super(MessagingExtension.SUBSYSTEM_NAME, new MessagingExtension());
     }
 
     @Override
     protected String getSubsystemXml() throws IOException {
-        return readResource("subsystem_13_1.xml");
+        return readResource("subsystem_14_0.xml");
     }
 
     @Override
     protected String getSubsystemXsdPath() throws IOException {
-        return "schema/wildfly-messaging-activemq_13_1.xsd";
+        return "schema/wildfly-messaging-activemq_14_0.xsd";
     }
 
     @Override
@@ -100,12 +104,17 @@ public class MessagingActiveMQSubsystem_13_1_TestCase extends AbstractSubsystemB
     /////////////////////////////////////////
     @Test
     public void testHAPolicyConfiguration() throws Exception {
-        standardSubsystemTest("subsystem_13_1_ha-policy.xml");
+        standardSubsystemTest("subsystem_14_0_ha-policy.xml");
     }
 
     ///////////////////////
     // Transformers test //
     ///////////////////////
+    @Test
+    public void testTransformersWildfly26_1() throws Exception {
+        testTransformers(ModelTestControllerVersion.MASTER, MessagingExtension.VERSION_13_1_0);
+    }
+
     @Test
     public void testTransformersWildfly25() throws Exception {
         testTransformers(ModelTestControllerVersion.MASTER, MessagingExtension.VERSION_13_0_0);
@@ -124,7 +133,7 @@ public class MessagingActiveMQSubsystem_13_1_TestCase extends AbstractSubsystemB
     private void testTransformers(ModelTestControllerVersion controllerVersion, ModelVersion messagingVersion) throws Exception {
         //Boot up empty controllers with the resources needed for the ops coming from the xml to work
         KernelServicesBuilder builder = createKernelServicesBuilder(createAdditionalInitialization())
-                .setSubsystemXmlResource("subsystem_13_1_transform.xml");
+                .setSubsystemXmlResource("subsystem_14_0_transform.xml");
         builder.createLegacyKernelServicesBuilder(createAdditionalInitialization(), controllerVersion, messagingVersion)
                 .addMavenResourceURL(getMessagingActiveMQGAV(controllerVersion))
                 .addMavenResourceURL(getActiveMQDependencies(controllerVersion))
@@ -161,14 +170,20 @@ public class MessagingActiveMQSubsystem_13_1_TestCase extends AbstractSubsystemB
         assertTrue(mainServices.isSuccessfulBoot());
         assertTrue(mainServices.getLegacyServices(messagingVersion).isSuccessfulBoot());
 
-        List<ModelNode> ops = builder.parseXmlResource("subsystem_13_1_reject_transform.xml");
+        List<ModelNode> ops = builder.parseXmlResource("subsystem_14_0_reject_transform.xml");
 //        System.out.println("ops = " + ops);
         PathAddress subsystemAddress = PathAddress.pathAddress(SUBSYSTEM_PATH);
 
         FailedOperationTransformationConfig config = new FailedOperationTransformationConfig();
-        config.addFailedAttribute(subsystemAddress.append(SERVER_PATH),
-                        new FailedOperationTransformationConfig.NewAttributesConfig(
-                                ServerDefinition.ADDRESS_QUEUE_SCAN_PERIOD));
+
+        config.addFailedAttribute(subsystemAddress.append(EXTERNAL_JMS_QUEUE_PATH),
+                new FailedOperationTransformationConfig.NewAttributesConfig(ConnectionFactoryAttributes.External.ENABLE_AMQ1_PREFIX));
+        config.addFailedAttribute(subsystemAddress.append(EXTERNAL_JMS_TOPIC_PATH),
+                new FailedOperationTransformationConfig.NewAttributesConfig(ConnectionFactoryAttributes.External.ENABLE_AMQ1_PREFIX));
+        config.addFailedAttribute(subsystemAddress.append(SERVER_PATH, BRIDGE_PATH), new FailedOperationTransformationConfig.NewAttributesConfig(BridgeDefinition.ROUTING_TYPE));
+        config.addFailedAttribute(subsystemAddress.append(SERVER_PATH), new FailedOperationTransformationConfig.NewAttributesConfig(
+                ServerDefinition.ADDRESS_QUEUE_SCAN_PERIOD
+        ));
         ModelTestUtils.checkFailedTransformedBootOperations(mainServices, messagingVersion, ops, config);
         mainServices.shutdown();
     }
@@ -182,9 +197,10 @@ public class MessagingActiveMQSubsystem_13_1_TestCase extends AbstractSubsystemB
 
     @Override
     protected AdditionalInitialization createAdditionalInitialization() {
-        return AdditionalInitialization.withCapabilities(ClusteringRequirement.COMMAND_DISPATCHER_FACTORY.resolve("ee"),
-                ClusteringDefaultRequirement.COMMAND_DISPATCHER_FACTORY.getName(),
-                JGroupsDefaultRequirement.CHANNEL_FACTORY.getName(),
+        return AdditionalInitialization.withCapabilities(RuntimeCapability.resolveCapabilityName(ClusteringServiceDescriptor.COMMAND_DISPATCHER_FACTORY, "ee"),
+                RuntimeCapability.resolveCapabilityName(LegacyClusteringServiceDescriptor.COMMAND_DISPATCHER_FACTORY, "ee"),
+                ClusteringServiceDescriptor.DEFAULT_COMMAND_DISPATCHER_FACTORY.getName(),
+                LegacyClusteringServiceDescriptor.DEFAULT_COMMAND_DISPATCHER_FACTORY.getName(),
                 Capabilities.ELYTRON_DOMAIN_CAPABILITY,
                 Capabilities.ELYTRON_DOMAIN_CAPABILITY + ".elytronDomain",
                 CredentialReference.CREDENTIAL_STORE_CAPABILITY + ".cs1",
