@@ -27,6 +27,7 @@ import org.eclipse.microprofile.health.HealthCheckResponse;
 import org.eclipse.microprofile.health.Liveness;
 import org.eclipse.microprofile.health.Readiness;
 import org.eclipse.microprofile.health.Startup;
+import org.jboss.as.server.moduleservice.ServiceModuleLoader;
 import org.jboss.modules.Module;
 import org.wildfly.extension.microprofile.health.MicroProfileHealthReporter;
 
@@ -48,12 +49,15 @@ public class CDIExtension implements Extension {
     private final List<HealthCheck> startupChecks = new ArrayList<>();
     private HealthCheck defaultReadinessCheck;
     private HealthCheck defaultStartupCheck;
+    private final Config config;
+    private final String deploymentName;
 
 
     public CDIExtension(MicroProfileHealthReporter healthReporter, Module module) {
         this.reporter = healthReporter;
         this.module = module;
-
+        this.config = ConfigProvider.getConfig(this.module.getClassLoader());
+        this.deploymentName = module.getName().replace(ServiceModuleLoader.MODULE_PREFIX, "");
     }
 
     /**
@@ -66,25 +70,27 @@ public class CDIExtension implements Extension {
         addHealthChecks(Liveness.Literal.INSTANCE, reporter::addLivenessCheck, livenessChecks);
         addHealthChecks(Readiness.Literal.INSTANCE, reporter::addReadinessCheck, readinessChecks);
         addHealthChecks(Startup.Literal.INSTANCE, reporter::addStartupCheck, startupChecks);
-        reporter.setUserChecksProcessed(true);
+
+        final boolean disableDefaultProcedures = config.getOptionalValue(MP_HEALTH_DISABLE_DEFAULT_PROCEDURES, Boolean.class).orElse(false);
         if (readinessChecks.isEmpty()) {
-            Config config = ConfigProvider.getConfig(module.getClassLoader());
-            boolean disableDefaultprocedure = config.getOptionalValue(MP_HEALTH_DISABLE_DEFAULT_PROCEDURES, Boolean.class).orElse(false);
-            if (!disableDefaultprocedure) {
+            if (!disableDefaultProcedures) {
                 // no readiness probe are present in the deployment. register a readiness check so that the deployment is considered ready
                 defaultReadinessCheck = new DefaultReadinessHealthCheck(module.getName());
                 reporter.addReadinessCheck(defaultReadinessCheck, module.getClassLoader());
             }
         }
         if (startupChecks.isEmpty()) {
-            Config config = ConfigProvider.getConfig(module.getClassLoader());
-            boolean disableDefaultprocedure = config.getOptionalValue(MP_HEALTH_DISABLE_DEFAULT_PROCEDURES, Boolean.class).orElse(false);
-            if (!disableDefaultprocedure) {
+            if (!disableDefaultProcedures) {
                 // no startup probes are present in the deployment. register a startup check so that the deployment is considered started
                 defaultStartupCheck = new DefaultStartupHealthCheck(module.getName());
                 reporter.addStartupCheck(defaultStartupCheck, module.getClassLoader());
             }
         }
+        // Track per-deployment configuration.
+        // Specifically, see https://issues.redhat.com/browse/WFLY-19147 - let the per-application
+        // `mp.health.disable-default-procedures` configuration setting affect the Health checks response global server
+        // configuration.
+        reporter.addDeploymentConfiguration(deploymentName, disableDefaultProcedures);
     }
 
     private void addHealthChecks(AnnotationLiteral qualifier,
@@ -114,6 +120,11 @@ public class CDIExtension implements Extension {
             reporter.removeStartupCheck(defaultStartupCheck);
             defaultStartupCheck = null;
         }
+        // Remove a deployment configuration tracker.
+        // Specifically, https://issues.redhat.com/browse/WFLY-20325 - remove the per-application
+        // `mp.health.disable-default-procedures` configuration setting affect the Health checks response global server
+        // configuration
+        reporter.removeDeploymentConfiguration(deploymentName);
 
         instance = null;
     }
