@@ -1,28 +1,10 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2017, Red Hat Middleware LLC, and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 
 package org.wildfly.extension.mod_cluster;
 
-import static org.jboss.as.clustering.dmr.ModelNodes.optionalString;
 import static org.wildfly.extension.mod_cluster.ModClusterLogger.ROOT_LOGGER;
 import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefinition.Attribute.ADVERTISE;
 import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefinition.Attribute.ADVERTISE_SECURITY_KEY;
@@ -37,7 +19,6 @@ import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefini
 import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefinition.Attribute.NODE_TIMEOUT;
 import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefinition.Attribute.PING;
 import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefinition.Attribute.PROXIES;
-import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefinition.Attribute.PROXY_LIST;
 import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefinition.Attribute.PROXY_URL;
 import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefinition.Attribute.SESSION_DRAINING_STRATEGY;
 import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefinition.Attribute.SMAX;
@@ -50,12 +31,9 @@ import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefini
 import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefinition.Attribute.TTL;
 import static org.wildfly.extension.mod_cluster.ProxyConfigurationResourceDefinition.Attribute.WORKER_TIMEOUT;
 
-import javax.net.ssl.SSLContext;
 import java.net.InetSocketAddress;
 import java.net.NetworkInterface;
 import java.net.SocketException;
-import java.net.UnknownHostException;
-import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
@@ -68,6 +46,7 @@ import java.util.concurrent.TimeUnit;
 import java.util.function.Consumer;
 import java.util.function.Function;
 import java.util.function.Supplier;
+import javax.net.ssl.SSLContext;
 
 import org.jboss.as.clustering.controller.CapabilityServiceNameProvider;
 import org.jboss.as.clustering.controller.CommonUnaryRequirement;
@@ -79,14 +58,10 @@ import org.jboss.as.network.ManagedBinding;
 import org.jboss.as.network.OutboundSocketBinding;
 import org.jboss.as.network.SocketBinding;
 import org.jboss.dmr.ModelNode;
-import org.jboss.modcluster.ModClusterService;
-import org.jboss.modcluster.Utils;
 import org.jboss.modcluster.config.ModClusterConfiguration;
 import org.jboss.modcluster.config.ProxyConfiguration;
 import org.jboss.modcluster.config.builder.ModClusterConfigurationBuilder;
-import org.jboss.modcluster.config.impl.ModClusterConfig;
 import org.jboss.modcluster.config.impl.SessionDrainingStrategyEnum;
-import org.jboss.modcluster.mcmp.impl.JSSESocketFactory;
 import org.jboss.msc.Service;
 import org.jboss.msc.service.ServiceBuilder;
 import org.jboss.msc.service.ServiceController;
@@ -102,7 +77,7 @@ import org.wildfly.clustering.service.SupplierDependency;
 /**
  * @author Radoslav Husar
  */
- public class ProxyConfigurationServiceConfigurator extends CapabilityServiceNameProvider implements ResourceServiceConfigurator, Supplier<ModClusterConfiguration>, Consumer<ModClusterConfiguration> {
+public class ProxyConfigurationServiceConfigurator extends CapabilityServiceNameProvider implements ResourceServiceConfigurator, Supplier<ModClusterConfiguration>, Consumer<ModClusterConfiguration> {
 
     private volatile SupplierDependency<SocketBinding> advertiseSocketDependency = null;
     private final List<SupplierDependency<OutboundSocketBinding>> outboundSocketBindings = new LinkedList<>();
@@ -119,15 +94,13 @@ import org.wildfly.clustering.service.SupplierDependency;
         return super.getServiceName().append("configuration");
     }
 
-    @SuppressWarnings("deprecation")
     @Override
     public ServiceConfigurator configure(OperationContext context, ModelNode model) throws OperationFailedException {
 
         // Advertise
-        optionalString(ADVERTISE_SOCKET.resolveModelAttribute(context, model))
-                .ifPresent(advertiseSocketRef -> this.advertiseSocketDependency = new ServiceSupplierDependency<>(context.getCapabilityServiceName(CommonUnaryRequirement.SOCKET_BINDING.getName(), advertiseSocketRef, SocketBinding.class)));
-        optionalString(ADVERTISE_SECURITY_KEY.resolveModelAttribute(context, model))
-                .ifPresent(securityKey -> builder.advertise().setAdvertiseSecurityKey(securityKey));
+        String advertiseSocket = ADVERTISE_SOCKET.resolveModelAttribute(context, model).asStringOrNull();
+        this.advertiseSocketDependency = (advertiseSocket != null) ? new ServiceSupplierDependency<>(CommonUnaryRequirement.SOCKET_BINDING.getServiceName(context, advertiseSocket)) : null;
+        this.builder.advertise().setAdvertiseSecurityKey(ADVERTISE_SECURITY_KEY.resolveModelAttribute(context, model).asStringOrNull());
 
         // MCMP
 
@@ -198,21 +171,38 @@ import org.wildfly.clustering.service.SupplierDependency;
                 .setStickySession(STICKY_SESSION.resolveModelAttribute(context, model).asBoolean())
                 .setStickySessionRemove(STICKY_SESSION_REMOVE.resolveModelAttribute(context, model).asBoolean())
                 .setStickySessionForce(STICKY_SESSION_FORCE.resolveModelAttribute(context, model).asBoolean())
-                .setWorkerTimeout(WORKER_TIMEOUT.resolveModelAttribute(context, model).asInt())
                 .setMaxAttempts(MAX_ATTEMPTS.resolveModelAttribute(context, model).asInt())
         ;
 
+        ModelNode node = WORKER_TIMEOUT.resolveModelAttribute(context, model);
+        if (node.isDefined()) {
+            builder.balancer().setWorkerTimeout(node.asInt());
+        }
+
         // Node
 
         builder.node()
                 .setFlushPackets(FLUSH_PACKETS.resolveModelAttribute(context, model).asBoolean())
-                .setFlushWait(FLUSH_WAIT.resolveModelAttribute(context, model).asInt())
                 .setPing(PING.resolveModelAttribute(context, model).asInt())
-                .setSmax(SMAX.resolveModelAttribute(context, model).asInt())
-                .setTtl(TTL.resolveModelAttribute(context, model).asInt())
-                .setNodeTimeout(NODE_TIMEOUT.resolveModelAttribute(context, model).asInt())
         ;
-        ModelNode node = BALANCER.resolveModelAttribute(context, model);
+
+        node = FLUSH_WAIT.resolveModelAttribute(context, model);
+        if (node.isDefined()) {
+            builder.node().setFlushWait(node.asInt());
+        }
+        node = SMAX.resolveModelAttribute(context, model);
+        if (node.isDefined()) {
+            builder.node().setSmax(node.asInt());
+        }
+        node = TTL.resolveModelAttribute(context, model);
+        if (node.isDefined()) {
+            builder.node().setTtl(node.asInt());
+        }
+        node = NODE_TIMEOUT.resolveModelAttribute(context, model);
+        if (node.isDefined()) {
+            builder.node().setNodeTimeout(node.asInt());
+        }
+        node = BALANCER.resolveModelAttribute(context, model);
         if (node.isDefined()) {
             builder.node().setBalancer(node.asString());
         }
@@ -228,36 +218,6 @@ import org.wildfly.clustering.service.SupplierDependency;
             }
         }
 
-        String proxyList = PROXY_LIST.resolveModelAttribute(context, model).asStringOrNull();
-        if (proxyList != null && proxyList.length() != 0) {
-            Collection<ProxyConfiguration> proxyConfigurations;
-
-            String[] tokens = proxyList.split(",");
-            proxyConfigurations = new ArrayList<>(tokens.length);
-
-            for (String token : tokens) {
-                try {
-                    final InetSocketAddress remoteAddress = Utils.parseSocketAddress(token.trim(), ModClusterService.DEFAULT_PORT);
-                    proxyConfigurations.add(new ProxyConfiguration() {
-                        @Override
-                        public InetSocketAddress getRemoteAddress() {
-                            return remoteAddress;
-                        }
-
-                        @Override
-                        public InetSocketAddress getLocalAddress() {
-                            return null;
-                        }
-                    });
-                } catch (UnknownHostException e) {
-                    throw new IllegalArgumentException(e);
-                }
-            }
-
-            builder.mcmp().setProxyConfigurations(proxyConfigurations);
-        }
-
-
         // Elytron-based security support
 
         node = SSL_CONTEXT.resolveModelAttribute(context, model);
@@ -265,50 +225,6 @@ import org.wildfly.clustering.service.SupplierDependency;
             this.sslContextDependency = new ServiceSupplierDependency<>(CommonUnaryRequirement.SSL_CONTEXT.getServiceName(context, node.asString()));
         }
 
-        // Legacy security support
-
-        if (model.get(SSLResourceDefinition.PATH.getKeyValuePair()).isDefined()) {
-            if (node.isDefined()) {
-                throw ROOT_LOGGER.bothElytronAndLegacySslContextDefined();
-            }
-            ModelNode sslModel = model.get(SSLResourceDefinition.PATH.getKeyValuePair());
-
-            ModClusterConfig sslConfiguration = new ModClusterConfig();
-
-            node = SSLResourceDefinition.Attribute.KEY_ALIAS.resolveModelAttribute(context, sslModel);
-            if (node.isDefined()) {
-                sslConfiguration.setSslKeyAlias(node.asString());
-            }
-            node = SSLResourceDefinition.Attribute.PASSWORD.resolveModelAttribute(context, sslModel);
-            if (node.isDefined()) {
-                String password = node.asString();
-                sslConfiguration.setSslTrustStorePassword(password);
-                sslConfiguration.setSslKeyStorePassword(password);
-            }
-            node = SSLResourceDefinition.Attribute.CERTIFICATE_KEY_FILE.resolveModelAttribute(context, sslModel);
-            if (node.isDefined()) {
-                sslConfiguration.setSslKeyStore(node.asString());
-            }
-            node = SSLResourceDefinition.Attribute.CIPHER_SUITE.resolveModelAttribute(context, sslModel);
-            if (node.isDefined()) {
-                sslConfiguration.setSslCiphers(node.asString());
-            }
-            node = SSLResourceDefinition.Attribute.PROTOCOL.resolveModelAttribute(context, sslModel);
-            if (node.isDefined()) {
-                sslConfiguration.setSslProtocol(node.asString());
-            }
-            node = SSLResourceDefinition.Attribute.CA_CERTIFICATE_FILE.resolveModelAttribute(context, sslModel);
-            if (node.isDefined()) {
-                sslConfiguration.setSslTrustStore(node.asString());
-            }
-            node = SSLResourceDefinition.Attribute.CA_REVOCATION_URL.resolveModelAttribute(context, sslModel);
-            if (node.isDefined()) {
-                sslConfiguration.setSslCrlFile(node.asString());
-            }
-
-            builder.mcmp().setSocketFactory(new JSSESocketFactory(sslConfiguration));
-        }
-
         return this;
     }
 
@@ -331,7 +247,7 @@ import org.wildfly.clustering.service.SupplierDependency;
             final SocketBinding binding = advertiseSocketDependency.get();
             builder.advertise()
                     .setAdvertiseSocketAddress(binding.getMulticastSocketAddress())
-                    .setAdvertiseInterface(binding.getNetworkInterfaceBinding().getAddress())
+                    .setAdvertiseInterface(binding.getNetworkInterfaceBinding().getNetworkInterfaces().stream().findFirst().orElse(null))
             ;
 
             // Register the binding with named registry as bound (WFLY-11447)
