@@ -1,28 +1,12 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2012, Red Hat, Inc., and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 package org.jboss.as.txn.subsystem;
 
 import org.jboss.as.controller.SimpleAttributeDefinition;
 import org.jboss.as.controller.descriptions.ModelDescriptionConstants;
+import org.jboss.as.txn.logging.TransactionLogger;
 import org.jboss.dmr.ModelNode;
 import org.jboss.staxmapper.XMLElementReader;
 import org.jboss.staxmapper.XMLExtendedStreamReader;
@@ -52,15 +36,22 @@ import static org.jboss.as.controller.parsing.ParseUtils.unexpectedElement;
  */
 class TransactionSubsystem14Parser implements XMLStreamConstants, XMLElementReader<List<ModelNode>> {
 
-    public static final TransactionSubsystem14Parser INSTANCE = new TransactionSubsystem14Parser(Namespace.TRANSACTIONS_1_4);
-
     private final Namespace validNamespace;
-    TransactionSubsystem14Parser(Namespace validNamespace) {
+    protected TransactionSubsystem14Parser(Namespace validNamespace) {
         this.validNamespace = validNamespace;
+        this.relativeToHasDefaultValue = true;
+    }
+    TransactionSubsystem14Parser(){
+        this(Namespace.TRANSACTIONS_1_4);
     }
 
+
     protected boolean choiceObjectStoreEncountered;
 
+    protected boolean needsDefaultRelativeTo;
+
+    protected boolean relativeToHasDefaultValue;
+
     protected Namespace getExpectedNamespace() {
         return validNamespace;
     }
@@ -98,6 +89,7 @@ class TransactionSubsystem14Parser implements XMLStreamConstants, XMLElementRead
         final EnumSet<Element> required = EnumSet.of(Element.RECOVERY_ENVIRONMENT, Element.CORE_ENVIRONMENT);
         final EnumSet<Element> encountered = EnumSet.noneOf(Element.class);
         choiceObjectStoreEncountered = false;
+        needsDefaultRelativeTo = true;
         while (reader.hasNext() && reader.nextTag() != END_ELEMENT) {
             if (Namespace.forUri(reader.getNamespaceURI()) != getExpectedNamespace()) {
                 throw unexpectedElement(reader);
@@ -109,6 +101,11 @@ class TransactionSubsystem14Parser implements XMLStreamConstants, XMLElementRead
             }
             readElement(reader, element, list, subsystem, logStoreOperation);
         }
+
+        if(needsDefaultRelativeTo && relativeToHasDefaultValue) {
+            TransactionSubsystemRootResourceDefinition.OBJECT_STORE_RELATIVE_TO.parseAndSetParameter("jboss.server.data.dir", subsystem, reader);
+        }
+
         if (!required.isEmpty()) {
             throw missingRequiredElement(reader, required);
         }
@@ -136,14 +133,14 @@ class TransactionSubsystem14Parser implements XMLStreamConstants, XMLElementRead
                 parseJts(reader, subsystemOperation);
                 break;
             }
-            case USEHORNETQSTORE: {
+            case USE_HORNETQ_STORE: {
                 if (choiceObjectStoreEncountered) {
                     throw unexpectedElement(reader);
                 }
                 choiceObjectStoreEncountered = true;
 
-                parseUsehornetqstore(reader, logStoreOperation, subsystemOperation);
-                subsystemOperation.get(CommonAttributes.USEHORNETQSTORE).set(true);
+                parseUseJournalstore(reader, logStoreOperation, subsystemOperation);
+                subsystemOperation.get(CommonAttributes.USE_JOURNAL_STORE).set(true);
                 break;
             }
             case JDBC_STORE: {
@@ -163,12 +160,16 @@ class TransactionSubsystem14Parser implements XMLStreamConstants, XMLElementRead
     }
 
     protected void parseJts(final XMLExtendedStreamReader reader, final ModelNode operation) throws XMLStreamException {
+        // no attributes
+        if (reader.getAttributeCount() > 0) {
+            throw unexpectedAttribute(reader, 0);
+        }
         operation.get(CommonAttributes.JTS).set(true);
         requireNoContent(reader);
     }
 
-    protected void parseUsehornetqstore(final XMLExtendedStreamReader reader, final ModelNode logStoreOperation, final ModelNode operation) throws XMLStreamException {
-        logStoreOperation.get(LogStoreConstants.LOG_STORE_TYPE.getName()).set("hornetq");
+    protected void parseUseJournalstore(final XMLExtendedStreamReader reader, final ModelNode logStoreOperation, final ModelNode operation) throws XMLStreamException {
+        logStoreOperation.get(LogStoreConstants.LOG_STORE_TYPE.getName()).set("journal");
 
         // Handle attributes
         final int count = reader.getAttributeCount();
@@ -178,7 +179,7 @@ class TransactionSubsystem14Parser implements XMLStreamConstants, XMLElementRead
             final Attribute attribute = Attribute.forName(reader.getAttributeLocalName(i));
             switch (attribute) {
                 case ENABLE_ASYNC_IO:
-                    TransactionSubsystemRootResourceDefinition.HORNETQ_STORE_ENABLE_ASYNC_IO.parseAndSetParameter(value, operation, reader);
+                    TransactionSubsystemRootResourceDefinition.JOURNAL_STORE_ENABLE_ASYNC_IO.parseAndSetParameter(value, operation, reader);
                     break;
                 default:
                     throw unexpectedAttribute(reader, i);
@@ -198,9 +199,13 @@ class TransactionSubsystem14Parser implements XMLStreamConstants, XMLElementRead
             switch (attribute) {
                 case RELATIVE_TO:
                     TransactionSubsystemRootResourceDefinition.OBJECT_STORE_RELATIVE_TO.parseAndSetParameter(value, operation, reader);
+                    needsDefaultRelativeTo = false;
                     break;
                 case PATH:
                     TransactionSubsystemRootResourceDefinition.OBJECT_STORE_PATH.parseAndSetParameter(value, operation, reader);
+                    if (!value.equals(TransactionSubsystemRootResourceDefinition.OBJECT_STORE_PATH.getDefaultValue().asString())) {
+                        needsDefaultRelativeTo = false;
+                    }
                     break;
                 default:
                     throw unexpectedAttribute(reader, i);
@@ -302,7 +307,7 @@ class TransactionSubsystem14Parser implements XMLStreamConstants, XMLElementRead
      *
      * @param reader
      * @return ModelNode for the core-environment
-     * @throws javax.xml.stream.XMLStreamException
+     * @throws XMLStreamException
      *
      */
     protected void parseCoreEnvironmentElement(final XMLExtendedStreamReader reader, final ModelNode operation) throws XMLStreamException {
@@ -317,11 +322,8 @@ class TransactionSubsystem14Parser implements XMLStreamConstants, XMLElementRead
                     TransactionSubsystemRootResourceDefinition.NODE_IDENTIFIER.parseAndSetParameter(value, operation, reader);
                     break;
                 case PATH:
-                    TransactionSubsystemRootResourceDefinition.PATH.parseAndSetParameter(value, operation, reader);
-                    break;
                 case RELATIVE_TO:
-                    TransactionSubsystemRootResourceDefinition.RELATIVE_TO.parseAndSetParameter(value, operation, reader);
-                    break;
+                    throw TransactionLogger.ROOT_LOGGER.unsupportedAttribute(attribute.getLocalName(), reader.getLocation());
                 default:
                     throw unexpectedAttribute(reader, i);
             }
@@ -355,10 +357,14 @@ class TransactionSubsystem14Parser implements XMLStreamConstants, XMLElementRead
      * @param reader
      * @param coreEnvironmentAdd
      * @return
-     * @throws javax.xml.stream.XMLStreamException
+     * @throws XMLStreamException
      *
      */
     protected void parseProcessIdEnvironmentElement(XMLExtendedStreamReader reader, ModelNode coreEnvironmentAdd) throws XMLStreamException {
+        // no attributes
+        if (reader.getAttributeCount() > 0) {
+            throw unexpectedAttribute(reader, 0);
+        }
 
         // elements
         boolean encountered = false;
@@ -370,6 +376,9 @@ class TransactionSubsystem14Parser implements XMLStreamConstants, XMLElementRead
                         throw unexpectedElement(reader);
                     }
                     encountered = true;
+                    if (reader.getAttributeCount() > 0) {
+                        throw unexpectedAttribute(reader, 0);
+                    }
                     coreEnvironmentAdd.get(TransactionSubsystemRootResourceDefinition.PROCESS_ID_UUID.getName()).set(true);
                     requireNoContent(reader);
                     break;
@@ -438,7 +447,7 @@ class TransactionSubsystem14Parser implements XMLStreamConstants, XMLElementRead
                     TransactionSubsystemRootResourceDefinition.RECOVERY_LISTENER.parseAndSetParameter(value, operation, reader);
                     break;
                 default:
-                    unexpectedAttribute(reader, i);
+                    throw unexpectedAttribute(reader, i);
             }
         }
 
