@@ -26,7 +26,6 @@ import org.jboss.dmr.ModelNode;
 import org.jboss.dmr.Property;
 import org.jboss.msc.service.ServiceBuilder;
 import org.jboss.msc.service.ServiceController;
-import org.wildfly.extension.undertow.session.DistributableServerRuntimeHandler;
 
 /**
  * @author <a href="mailto:tomaz.cerar@redhat.com">Tomaz Cerar</a> (c) 2013 Red Hat Inc.
@@ -55,7 +54,7 @@ final class ServerAdd extends AbstractAddStepHandler {
         if (isDefaultServer) { //only install for default server
             final CapabilityServiceBuilder<?> csb = context.getCapabilityServiceTarget().addCapability(CommonWebServer.CAPABILITY);
             final Consumer<WebServerService> wssConsumer = csb.provides(CommonWebServer.CAPABILITY, CommonWebServer.SERVICE_NAME);
-            final Supplier<Server> sSupplier = csb.requiresCapability(Capabilities.CAPABILITY_SERVER, Server.class, name);
+            final Supplier<Server> sSupplier = csb.requires(Server.SERVICE_DESCRIPTOR, name);
             csb.setInstance(new WebServerService(wssConsumer, sSupplier));
             csb.setInitialMode(ServiceController.Mode.PASSIVE);
 
@@ -65,8 +64,8 @@ final class ServerAdd extends AbstractAddStepHandler {
             csb.install();
         }
 
-        for (DistributableServerRuntimeHandler handler : ServiceLoader.load(DistributableServerRuntimeHandler.class, DistributableServerRuntimeHandler.class.getClassLoader())) {
-            handler.execute(context, name);
+        for (ServerServiceInstallerProvider factory : ServiceLoader.load(ServerServiceInstallerProvider.class, ServerServiceInstallerProvider.class.getClassLoader())) {
+            factory.getServiceInstaller(name).install(context);
         }
     }
 
